PAWpySeed: Member List

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

pawpyseed.core.noncollinear.NCLWavefunction Member List

This is the complete list of members for pawpyseed.core.noncollinear.NCLWavefunction, including all inherited members.

__init__(self, struct, pwf, cr, dim, symprec=1e-4, setup_projectors=False) | pawpyseed.core.noncollinear.NCLWavefunction |
band_props | pawpyseed.core.noncollinear.NCLWavefunction |
check_c_projectors(self) | pawpyseed.core.wavefunction.Wavefunction |
cr | pawpyseed.core.noncollinear.NCLWavefunction |
desymmetrized_copy(self, allkpts=None, weights=None) | pawpyseed.core.noncollinear.NCLWavefunction |
dim | pawpyseed.core.noncollinear.NCLWavefunction |
from_atomate_directory(path, setup_projectors=False) | pawpyseed.core.wavefunction.Wavefunction | static
from_directory(path, setup_projectors=False) | pawpyseed.core.noncollinear.NCLWavefunction | static
from_files(struct="CONTCAR", wavecar="WAVECAR", cr="POTCAR", vr="vasprun.xml", setup_projectors=False) | pawpyseed.core.noncollinear.NCLWavefunction | static
get_kpt_mapping(self, allkpts, symprec=None, gen_trsym=True) | pawpyseed.core.wavefunction.Wavefunction |
get_nosym_kpoints(self, init_kpts=None, symprec=None, gen_trsym=True, fil_trsym=True) | pawpyseed.core.wavefunction.Wavefunction |
get_realspace_density(self, dim=None, bands=None) | pawpyseed.core.wavefunction.Wavefunction |
get_state_realspace(self, b, k, s, dim=None, remove_phase=False) | pawpyseed.core.wavefunction.Wavefunction |
num_elems | pawpyseed.core.wavefunction.Wavefunction |
num_sites | pawpyseed.core.wavefunction.Wavefunction |
structure | pawpyseed.core.noncollinear.NCLWavefunction |
symprec | pawpyseed.core.wavefunction.Wavefunction |
update_dim(self, dim) | pawpyseed.core.wavefunction.Wavefunction |
write_density_realspace(self, filename="PYAECCAR", dim=None, scale=1) | pawpyseed.core.noncollinear.NCLWavefunction |
pawpyseed::core::wavefunction::Wavefunction.write_density_realspace(self, filename="PYAECCAR", dim=None, scale=1, bands=None) | pawpyseed.core.wavefunction.Wavefunction |
write_state_realspace(self, b, k, s, fileprefix="", dim=None, scale=1) | pawpyseed.core.noncollinear.NCLWavefunction |
pawpyseed::core::wavefunction::Wavefunction.write_state_realspace(self, b, k, s, fileprefix="", dim=None, scale=1, remove_phase=False) | pawpyseed.core.wavefunction.Wavefunction |